Crate smash_svt

Crate smash_svt 

svt_lib

svt_lib is a library for reading and writing sound_volume_table.svt files from Super Smash Bros. for Nintendo 3DS and Wii U and Super Smash Bros. Ultimate.

Structs

SvtEntry
A group of audio gain parameters.
SvtFile
The container type for groups of audio gain parameters.